==> ochusha-0.4.5.7.tar.bz2: ochusha-0.4.5.7/lib/marshal.h <==

#ifndef __libochusha_marshal_MARSHAL_H__
#define __libochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:OBJECT (marshal.list:1) */
extern void libochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* BOOLEAN:OBJECT,INT,INT (marshal.list:2) */
extern void libochusha_marshal_BOOLEAN__OBJECT_INT_INT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* BOOLEAN:OBJECT,INT,STRING (marshal.list:3) */
extern void libochusha_marshal_BOOLEAN__OBJECT_INT_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:POINTER (marshal.list:4) */
#define libochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING (marshal.list:5) */
#define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:VOID (marshal.list:6) */
#define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:OBJECT,POINTER (marshal.list:7) */
extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* __libochusha_marshal_MARSHAL_H__ */

==> ochusha-0.4.9.tar.bz2: ochusha-0.4.9/lib/marshal.h <==

#ifndef __libochusha_marshal_MARSHAL_H__
#define __libochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:OBJECT (marshal.list:1) */
extern void libochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* BOOLEAN:OBJECT,INT,INT (marshal.list:2) */
extern void libochusha_marshal_BOOLEAN__OBJECT_INT_INT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* BOOLEAN:OBJECT,INT,STRING (marshal.list:3) */
extern void libochusha_marshal_BOOLEAN__OBJECT_INT_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* OBJECT:STRING (marshal.list:4) */
extern void libochusha_marshal_OBJECT__STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* OBJECT:INT,STRING,STRING (marshal.list:5) */
extern void libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:POINTER (marshal.list:6) */
#define libochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING (marshal.list:7) */
#define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:VOID (marshal.list:8) */
#define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:OBJECT,POINTER (marshal.list:9) */
extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* __libochusha_marshal_MARSHAL_H__ */
